@@ -4,6 +4,6 @@ from .views import home, model_form
 
 
 urlpatterns = [
-    path('', home, name='home'),
-    path('model_form/', model_form, name='model_form'),
+    path("", home, name="home"),
+    path("model_form/", model_form, name="model_form"),
 ]
