@@ -10,20 +10,19 @@ def home(request):
     if request.POST:
         form = BleachForm(request.POST)
         if form.is_valid():
-            return HttpResponseRedirect(request.path + '?ok')
+            return HttpResponseRedirect(request.path + "?ok")
     else:
         form = BleachForm()
 
-    return render(request, 'home.html', {'form': form})
+    return render(request, "home.html", {"form": form})
 
 
 def model_form(request):
-
     if request.POST:
         form = PersonForm(request.POST)
         if form.is_valid():
             form.save()
-            return HttpResponseRedirect('?ok')
+            return HttpResponseRedirect("?ok")
     else:
         form = PersonForm()
         try:
@@ -31,7 +30,11 @@ def model_form(request):
         except OperationalError:
             people = []
 
-        return render(request, 'model_form.html', {
-            'form': form,
-            'people': people,
-        })
+        return render(
+            request,
+            "model_form.html",
+            {
+                "form": form,
+                "people": people,
+            },
+        )
